@@ -11,18 +11,27 @@ use WebService::Slack::WebApi::Generator (
     },
     history => {
         channel   => 'Str',
+        count     => { isa => 'Int',  optional => 1 },
+        inclusive => { isa => 'Bool', optional => 1 },
         latest    => { isa => 'Str',  optional => 1 },
         oldest    => { isa => 'Str',  optional => 1 },
-        inclusive => { isa => 'Bool', optional => 1 },
-        count     => { isa => 'Int',  optional => 1 },
+        unreads   => { isa => 'Bool', optional => 1 },
+    },
+    list => {
+        cursor => { isa => 'Str',  optional => 1 },
+        limit  => { isa => 'Int',  optional => 1 },
     },
-    list => +{},
     mark => {
         channel => 'Str',
         ts      => 'Str',
     },
     open => {
-        user => 'Str',
+        user      => 'Str',
+        return_im => { isa => 'Bool', optional => 1 },
+    },
+    replies => {
+        channel   => 'Str',
+        thread_ts => 'Str',
     },
 );
 
